@@ -117,7 +117,7 @@ def get_icon(icon_path, icon_name, size=None, color=None, extra_classes=None):
 
     # cached icon doesn't exist or no cache configured, create and return icon
     try:
-        resp = requests.get(icon_path)
+        resp = requests.get(icon_path, timeout=20)
         if resp.status_code >= 400:
             # return f"Icon <{icon_path}> does not exist"
             return getattr(
@@ -155,7 +155,7 @@ def bs_icon(icon_name, size=None, color=None, extra_classes=None):
     base_url = getattr(
         settings,
         'BS_ICONS_BASE_URL',
-        'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.9.0/',
+        'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.4/',
     )
     icon_path = f'{base_url}icons/{icon_name}.svg'
 
@@ -189,7 +189,7 @@ def md_icon(icon_name, size=None, color=None, extra_classes=None):
     base_url = getattr(
         settings,
         'MD_ICONS_BASE_URL',
-        'https://cdn.jsdelivr.net/npm/@mdi/svg@6.9.96/'
+        'https://cdn.jsdelivr.net/npm/@mdi/svg@7.2.96/'
     )
     icon_path = f'{base_url}svg/{icon_name}.svg'
 
